@@ -842,7 +842,7 @@ static int out_width( char spec_char, int abb_size, int full_size,
  **********************************************************************
    NAME output_one
 
-   DESCRIPTION Use sprintf to print out one output spec
+   DESCRIPTION Use snprintf to print out one output spec
 
    ARGUMENTS
       IOARG out_buf      the buffer for printing (set to end of last print)
@@ -875,6 +875,8 @@ static int output_one( char **out_buf, TIME_DATE_STRUCT td,
   Sint print_val;
   int num_chars, i;
   char *print_str, *slash_pos = NULL;
+  size_t n_bytes_remaining = field_width+1; // it is unclear to me if we need to account for trailing null here
+    // We assume that all characters are single-byte.
 
   if( !out_buf || !(*out_buf ))
     return 0;
@@ -1054,21 +1056,27 @@ static int output_one( char **out_buf, TIME_DATE_STRUCT td,
     if( field_width > 0 )  /* have a field width */
     {
       if( field_width < num_chars ) /* insufficient space */
-	num_chars = sprintf( *out_buf, "%*.*s", field_width, field_width, 
+	num_chars = snprintf( *out_buf, n_bytes_remaining, "%*.*s", field_width, field_width, 
 			     print_str );
       else /* sufficient space */
-	num_chars = sprintf( *out_buf, "%*s", field_width, print_str );
+	num_chars = snprintf( *out_buf, n_bytes_remaining, "%*s", field_width, print_str );
       /* put slash back if necessary */
       if( slash_pos )
 	*slash_pos = '/';
 
-      if( num_chars != field_width )
-	return 0;
+      if (num_chars >= n_bytes_remaining){
+        return 0;
+      }
       *out_buf += num_chars;
       return 1;
     }
       
-    num_chars = sprintf( *out_buf, "%s", print_str );
+    /* We have not been told the size of the output buffer, so we need to assume it is big enough */
+    n_bytes_remaining = strlen(print_str) + 1;
+    num_chars = snprintf( *out_buf, n_bytes_remaining, "%s", print_str );
+    if (num_chars >= n_bytes_remaining){
+      return 0;
+    }
     /* put slash back if necessary */
     if( slash_pos )
       *slash_pos = '/';
@@ -1081,10 +1089,10 @@ static int output_one( char **out_buf, TIME_DATE_STRUCT td,
 
    if( zero_pad )
    {
-     num_chars = sprintf( *out_buf, "%0*d", field_width, print_val );
+     num_chars = snprintf( *out_buf, n_bytes_remaining, "%0*d", field_width, print_val );
      if( num_chars < field_width ) /* problem printing */
        return 0;
-     if( num_chars > field_width ) /* field too narrow, put in * characters */
+     if( num_chars >= n_bytes_remaining ) /* field too narrow, put in * characters */
        for( i = 0; i < field_width; i++ )
 	 *(*out_buf + i) = '*';
      *out_buf += field_width;
@@ -1094,10 +1102,10 @@ static int output_one( char **out_buf, TIME_DATE_STRUCT td,
 
    if( field_width > 0 )
    {
-     num_chars = sprintf( *out_buf, "%*d", field_width, print_val );
+     num_chars = snprintf( *out_buf, n_bytes_remaining, "%*d", field_width, print_val );
      if( num_chars < field_width )  /* problem printing */
        return 0;
-     if( num_chars > field_width ) /* field too narrow, put in * characters */
+     if( num_chars >= n_bytes_remaining ) /* field too narrow, put in * characters */
        for( i = 0; i < field_width; i++ )
 	 *(*out_buf + i) = '*';
      *out_buf += field_width;
@@ -1106,9 +1114,10 @@ static int output_one( char **out_buf, TIME_DATE_STRUCT td,
    }
 
    /* no particular width */
-
-  num_chars = sprintf( *out_buf, "%d", print_val );
-  if( num_chars < 1 )  /* problem printing */
+   /* We have not been told the size of the output buffer, so we need to assume it is big enough */
+  n_bytes_remaining = 250;
+  num_chars = snprintf( *out_buf, n_bytes_remaining, "%d", print_val );
+  if( num_chars >= n_bytes_remaining )  /* problem printing */
     return 0;
   *out_buf += num_chars;
   return 1;
